'''

cf-plot is a set of Python plotting routines for the contour, vector and line plots that
climate researchers commonly make.


See the cf-plot home page http://ajheaps.github.io/cf-plot for a gallery of plots and how to use cf-plot.


'''

__author__ = 'Andy Heaps - andy.heaps@ncas.ac.uk'
__date__ = '6th July 2020'
__version__ = '3.0.25'

from .cfplot import *


